@@ -97,15 +97,11 @@ namespace Oxygen
 
         GdkWindow* window(gtk_widget_get_window(widget));
         if(
-
-            // check window
-            window &&
-            gdk_window_get_window_type( window ) == GDK_WINDOW_CHILD &&
-
-            // check compositing
+            window && gdk_window_get_window_type( window ) == GDK_WINDOW_CHILD &&
             gdk_display_supports_composite( gtk_widget_get_display( widget ) ) &&
 
             // TODO: implement proper blacklist if there appear too many bad widgets/apps
+            // also remove when evolution-3.2.2 is not availabe anymore (it got fixed since then)
             G_OBJECT_TYPE_NAME(widget) != std::string("MessageList") )
         {
             ChildData data;
