@@ -1,6 +1,6 @@
 /*
 * this file is part of the oxygen gtk engine
-* Copyright (c) 2010 Hugo Pereira Da Costa <hugo.pereira@free.fr>
+* Copyright (c) 2010 Hugo Pereira Da Costa <hugo@oxygen-icons.org>
 *
 * This  library is free  software; you can  redistribute it and/or
 * modify it  under  the terms  of the  GNU Lesser  General  Public
@@ -95,7 +95,7 @@ namespace Oxygen
             << std::endl;
         #endif
 
-        if( data._target && gtk_widget_get_realized(data._target) )
+        if( data._target )
         { Gtk::gtk_widget_queue_draw( data._target, &data._dirtyRect ); }
 
         return FALSE;
